@@ -7,14 +7,7 @@
 #' @param vismodeldata (required) quantum catch color data. Can be either the result
 #' from \code{\link{vismodel}} or independently calculated data (in the form of a data frame
 #' with four columns, representing the avian cones).
-#' @param qcatch quantum catch values to use in the model. Can be either \code{Qi}, 
-#' \code{qi} or \code{fi} (defaults to \code{Qi}).
-#' \code{Qi}: Quantum catch for each photoreceptor 
-#' \code{qi}: Quantum catch normalized to the adapting background according 
-#' to the von Kries transformation.
-#' \code{fi}: Quantum catch according to Fechner law (the signal of the receptor
-#' channel is proportional to the logarithm of the quantum catch)
-#' 
+#'
 #' @return A data frame of class \code{tcs} consisting of the following rows:
 #' @return \code{u}, \code{s}, \code{m}, \code{l}: the quantum catch data used to
 #' calculate the remaining variables. NOTE: even if visual sistem is of type V-VIS,
@@ -38,29 +31,55 @@
 #' @references Stoddard, M. C., & Prum, R. O. (2008). Evolution of avian plumage color in a tetrahedral color space: A phylogenetic analysis of new world buntings. The American Naturalist, 171(6), 755-776.
 #' @references Endler, J. A., & Mielke, P. (2005). Comparing entire colour patterns as birds see them. Biological Journal Of The Linnean Society, 86(4), 405-431.
 
-tcs<- function(vismodeldata, qcatch=c('Qi','qi','fi'))
+tcs<- function(vismodeldata)
 {
 
 # check class, import selected sensitivity
 # make relative (in case not inherited relative)
 
-if(class(vismodeldata)=='vismodel'){
-	qcatch <- match.arg(qcatch)
-	dat <- data.frame(vismodeldata[qcatch])
-	names(dat) <- gsub(paste(qcatch,'.',sep=''), '', names(dat))
+# if(class(vismodeldata)=='vismodel'){
+	# qcatch <- match.arg(qcatch)
+	# dat <- data.frame(vismodeldata[qcatch])
+	# names(dat) <- gsub(paste(qcatch,'.',sep=''), '', names(dat))
 	
-  }else{
-  	dat <- vismodeldata
-  	}
+  # }else{
+  	# dat <- vismodeldata
+  	# }
+
+dat <- vismodeldata
   	
 if(any('v' %in% names(dat)))
   names(dat) <- gsub('v','u',names(dat))
+  
+# if the data frame has 4 columns, treat them as u/s/m/l
+if(any(attr(dat, 'visualsystem')=='none') & ncol(dat) == 4 & !all(c('u','s','m','l') %in% names(dat))){
+
+  names(dat) <- c('u','s','m','l')
+
+  warning(paste('Input data has four columns, but they are not named',
+  dQuote('u'),',',  dQuote('s'),',',  dQuote('m'),', and', dQuote('l'), '; treating them as such'))
+
+}
+
+if(!any(attr(dat, 'visualsystem')=='none') & ncol(dat) > 4 & !all(c('u','s','m','l') %in% names(dat))){
+
+  names(dat)[1:4] <- c('u','s','m','l')
+
+  warning(paste('Input data does not have columns named',
+  dQuote('u'),',',  dQuote('s'),',',  dQuote('m'),', and', dQuote('l'), '; treating first four columns as such'))
+
+}
+
+
   	
 if(!all(c('u','s','m','l') %in% names(dat)))
   stop(paste('Input data must have columns named',
   dQuote('u'),',',  dQuote('s'),',',  dQuote('m'),', and', dQuote('l')))
 
-dat <- dat[,c('u','s','m','l')]/rowSums(dat[,c('u','s','m','l')])
+if(!attr(dat, 'relative')){
+  dat <- dat[,c('u','s','m','l')]/rowSums(dat[,c('u','s','m','l')])
+  warning("Quantum catch are not relative, and have been transformed")
+}
 
 u <- dat[,'u']
 s <- dat[,'s']
@@ -145,4 +164,4 @@ res.p <- data.frame(u, s, m, l, u.r , s.r, m.r, l.r,
 res <- res.p
 class(res) <- c('tcs', 'data.frame')
 res
-}
\ No newline at end of file
+}
